@@ -13,11 +13,11 @@
 #' for \eqn{T} greater than or equal to 2.
 #'
 #' Orthopanels can accomodate unbalanced panel data, in that some
-#' respondents drop out early (attrition). It is assumed respondents
-#' will have observations up until they dropout and then NAs in
-#' subsequent waves. A future update will accommodate respondents that
-#' enter the panel late (refreshment). The estimation is conducted
-#' under the assumption that the data is missing at random.
+#' respondents may drop out early (attrition) and some respondents may
+#' enter the panel late (refreshment). It is assumed that once
+#' respondents enter the panel, they will have observations up until
+#' they dropout and then NAs in subsequent waves. The estimation is
+#' conducted under the assumption that the data is missing at random
 #' 
 #' @references
 #'
@@ -68,3 +68,39 @@ NULL
 #' @format A data frame with 5535 rows and 11 variables
 #' @name BES_panel
 NULL
+
+#' UK Company Data Panel
+#' 
+#' The dynamics of labour demand of firm \eqn{id} in the United Kingdom
+#' in year \eqn{year} as a function of real product wages, gross capital
+#' stock and industry output. This is done using the data used by
+#' Arellano and Bond (1991).
+#'
+#' A survey of 1845 respondents using 3 waves of panel survey data
+#' from the 2010 British Election Study. The variables are as follows:
+#'
+#' \itemize{
+#'   \item id case number
+#'   \item year time wave
+#'   \item n log of employment in firm \code{id} at time \code{year}
+#'   \item w natural log of the real product wage
+#'   \item k natural log of gross capital stock
+#'   \item ys natural log of industry output
+#'   \item l_w lag of \code{w}
+#'   \item l_k lag of \code{k}
+#'   \item l2_k two-step lag of \code{k}
+#'   \item l_ys lag of \code{ys}
+#'   \item l2_ys two-step lag of \code{ys}
+#'   \item yr1980..yr1984 time dummies
+#' }
+#'
+#' @format A data frame with 813 rows and 16 variables
+#' 
+#' @references
+#'
+#' Arrelano M., and Bond S. (1991) Some Tests of Specification for
+#' Panel Data: Monte Carlo Evidence and an Application to Employment
+#' Equations. \emph{Review of Economic Studies}, \bold{58(2)},
+#' 277--297.
+#' @name abond_panel
+NULL
